Index: gm/xfermodeimagefilter.cpp |
diff --git a/gm/xfermodeimagefilter.cpp b/gm/xfermodeimagefilter.cpp |
index 3efbbfad6a3bf8efbcbe358d105ca5de1d53d85b..80994a6ed8016124dfa25f1706307884b9c5f38b 100644 |
--- a/gm/xfermodeimagefilter.cpp |
+++ b/gm/xfermodeimagefilter.cpp |
@@ -138,8 +138,8 @@ protected: |
x = 0; |
y += fBitmap.height() + MARGIN; |
} |
- // Test NULL mode |
- filter.reset(SkXfermodeImageFilter::Create(NULL, background)); |
+ // Test nullptr mode |
+ filter.reset(SkXfermodeImageFilter::Create(nullptr, background)); |
paint.setImageFilter(filter); |
drawClippedBitmap(canvas, fBitmap, paint, x, y); |
x += fBitmap.width() + MARGIN; |